@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -33,9 +33,6 @@ from typing import (
     cast,
 )
 
-# External imports
-from PIL import Image
-
 if TYPE_CHECKING:
     from selenium.webdriver.remote.webdriver import WebDriver
 
@@ -50,6 +47,8 @@ from .state import State, curstate
 from .util import default_filename
 
 if TYPE_CHECKING:
+    from PIL import Image
+
     from ..models.plots import Plot
     from ..models.ui import UIElement
 
@@ -253,7 +252,11 @@ def get_screenshot_as_png(obj: UIElement | Document, *, driver: WebDriver | None
         aspect ratios. It is recommended to use the default ``fixed`` sizing mode.
 
     '''
-    from .webdriver import get_web_driver_device_pixel_ratio, scale_factor_less_than_web_driver_device_pixel_ratio, webdriver_control
+    from .webdriver import (
+        get_web_driver_device_pixel_ratio,
+        scale_factor_less_than_web_driver_device_pixel_ratio,
+        webdriver_control,
+    )
 
     with _tmp_html() as tmp:
         theme = (state or curstate()).document.theme
@@ -275,6 +278,7 @@ def get_screenshot_as_png(obj: UIElement | Document, *, driver: WebDriver | None
         [width, height, dpr] = _maximize_viewport(web_driver)
         png = web_driver.get_screenshot_as_png()
 
+    from PIL import Image
     return (Image.open(io.BytesIO(png))
                  .convert("RGBA")
                  .crop((0, 0, width*dpr, height*dpr))
