@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -36,14 +36,21 @@ from ..themes import default as default_theme
 from ..util.callback_manager import EventCallbackManager, PropertyCallbackManager
 from ..util.serialization import make_id
 from .docs import html_repr, process_example
-from .util import HasDocumentRef, collect_models, visit_value_and_its_immediate_references
+from .util import (
+    HasDocumentRef,
+    collect_models,
+    visit_value_and_its_immediate_references,
+)
 
 if TYPE_CHECKING:
     from ..core.has_props import Setter
     from ..core.query import SelectorType
     from ..document import Document
     from ..document.events import DocumentPatchedEvent
-    from ..models.callbacks import Callback as JSEventCallback, CustomCode as JSChangeCallback
+    from ..models.callbacks import (
+        Callback as JSEventCallback,
+        CustomCode as JSChangeCallback,
+    )
     from ..util.callback_manager import PropertyCallback
 
 #-----------------------------------------------------------------------------
