@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -65,7 +65,10 @@ from ...core.property_mixins import (
     ScalarTextProps,
 )
 from ...core.validation import error
-from ...core.validation.errors import BAD_COLUMN_NAME, NON_MATCHING_DATA_SOURCES_ON_LEGEND_ITEM_RENDERERS
+from ...core.validation.errors import (
+    BAD_COLUMN_NAME,
+    NON_MATCHING_DATA_SOURCES_ON_LEGEND_ITEM_RENDERERS,
+)
 from ...model import Model
 from ..formatters import TickFormatter
 from ..labeling import LabelingPolicy, NoOverlap
@@ -550,10 +553,12 @@ class ScaleBar(Annotation):
     Defines how the length of the bar is interpreted.
 
     This can either be:
+
     * ``"adaptive"`` - the computed length is fit into a set of ticks provided
-        be the dimensional model. If no ticks are provided, then the behavior
-        is the same as if ``"exact"`` sizing was used
+      be the dimensional model. If no ticks are provided, then the behavior
+      is the same as if ``"exact"`` sizing was used
     * ``"exact"`` - the computed length is used as-is
+
     """)
 
     bar_length = NonNegative(Either(Float, Int))(default=0.2, help="""
@@ -577,11 +582,12 @@ class ScaleBar(Annotation):
     The label template.
 
     This can use special variables:
+
     * ``@{value}`` The current value. Optionally can provide a number
-        formatter with e.g. ``@{value}{%.2f}``.
+      formatter with e.g. ``@{value}{%.2f}``.
     * ``@{unit}`` The unit of measure, by default in the short form.
-        Optionally can provide a format ``@{unit}{short}`` or
-        ``@{unit}{long}``.
+      Optionally can provide a format ``@{unit}{short}`` or ``@{unit}{long}``.
+
     """)
 
     label_text = Include(ScalarTextProps, prefix="label", help="""
