@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -109,7 +109,10 @@ __all__ = (
     'Ellipse',
     'Glyph',
     'HArea',
+    'HAreaStep',
     'HBar',
+    'HSpan',
+    'HStrip',
     'HexTile',
     'Image',
     'ImageRGBA',
@@ -130,7 +133,10 @@ __all__ = (
     'Step',
     'Text',
     'VArea',
+    'VAreaStep',
     'VBar',
+    'VSpan',
+    'VStrip',
     'Wedge',
     'XYGlyph',
 )
@@ -558,6 +564,49 @@ class HArea(LineGlyph, FillGlyph, HatchGlyph):
     The {prop} values for the horizontal directed area.
     """)
 
+class HAreaStep(FillGlyph, HatchGlyph):
+    ''' Render a horizontally directed area between two equal length sequences
+    of x-coordinates with the same y-coordinates using step lines.
+
+    '''
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+    __example__ = "examples/reference/models/HAreaStep.py"
+
+    _args = ('x1', 'x2', 'y')
+
+    x1 = NumberSpec(default=field("x1"), help="""
+    The x-coordinates for the points of one side of the area.
+    """)
+
+    x2 = NumberSpec(default=field("x2"), help="""
+    The x-coordinates for the points of the other side of the area.
+    """)
+
+    y = NumberSpec(default=field("y"), help="""
+    The y-coordinates for the points of the area.
+    """)
+
+    step_mode = Enum(StepMode, default="before", help="""
+    Where the step "level" should be drawn in relation to the x and y
+    coordinates. The parameter can assume one of three values:
+
+    * ``before``: (default) Draw step levels before each y-coordinate (no step before the first point)
+    * ``after``:  Draw step levels after each y-coordinate (no step after the last point)
+    * ``center``: Draw step levels centered on each y-coordinate
+    """)
+
+    fill_props = Include(ScalarFillProps, help="""
+    The {prop} values for the horizontal directed area.
+    """)
+
+    hatch_props = Include(HatchProps, help="""
+    The {prop} values for the horizontal directed area.
+    """)
+
 class HBar(LRTBGlyph):
     ''' Render horizontal bars, given a center coordinate, ``height`` and
     (``left``, ``right``) coordinates.
@@ -748,8 +797,8 @@ class Image(ImageBase):
     _extra_kws = {
         'palette': (
             'str or list[color value]',
-            'a palette to construct a value for the color mapper property from'
-        )
+            'a palette to construct a value for the color mapper property from',
+        ),
     }
 
     image = NumberSpec(default=field("image"), help="""
@@ -786,7 +835,7 @@ class ImageStack(ImageBase):
     ''' Render images given as 3D stacked arrays by flattening each stack into
     an RGBA image using a ``StackColorMapper``.
 
-    The 3D arrays have shape (ny, nx, nstack) where ``nstack` is the number of
+    The 3D arrays have shape (ny, nx, nstack) where ``nstack`` is the number of
     stacks. The ``color_mapper`` produces an RGBA value for each of the
     (ny, nx) pixels by combining array values in the ``nstack`` direction.
 
@@ -1540,6 +1589,49 @@ class VArea(FillGlyph, HatchGlyph):
     The {prop} values for the vertical directed area.
     """)
 
+class VAreaStep(FillGlyph, HatchGlyph):
+    ''' Render a vertically directed area between two equal length sequences
+    of y-coordinates with the same x-coordinates using step lines.
+
+    '''
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+    __example__ = "examples/reference/models/VAreaStep.py"
+
+    _args = ('x', 'y1', 'y2')
+
+    x = NumberSpec(default=field("x"), help="""
+    The x-coordinates for the points of the area.
+    """)
+
+    y1 = NumberSpec(default=field("y1"), help="""
+    The y-coordinates for the points of one side of the area.
+    """)
+
+    y2 = NumberSpec(default=field("y2"), help="""
+    The y-coordinates for the points of the other side of the area.
+    """)
+
+    step_mode = Enum(StepMode, default="before", help="""
+    Where the step "level" should be drawn in relation to the x and y
+    coordinates. The parameter can assume one of three values:
+
+    * ``before``: (default) Draw step levels before each x-coordinate (no step before the first point)
+    * ``after``:  Draw step levels after each x-coordinate (no step after the last point)
+    * ``center``: Draw step levels centered on each x-coordinate
+    """)
+
+    fill_props = Include(ScalarFillProps, help="""
+    The {prop} values for the vertical directed area.
+    """)
+
+    hatch_props = Include(HatchProps, help="""
+    The {prop} values for the vertical directed area.
+    """)
+
 class VBar(LRTBGlyph):
     ''' Render vertical bars, given a center coordinate, width and (top, bottom) coordinates.
 
@@ -1630,6 +1722,106 @@ class Wedge(XYGlyph, LineGlyph, FillGlyph, HatchGlyph):
     The {prop} values for the wedges.
     """)
 
+class HSpan(LineGlyph):
+    """ Horizontal lines of infinite width. """
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+    __example__ = "examples/reference/models/HSpan.py"
+
+    _args = ("y")
+
+    y = NumberSpec(default=field("y"), help="""
+    The y-coordinates of the spans.
+    """)
+
+    line_props = Include(LineProps, help="""
+    The {prop} values for the spans.
+    """)
+
+class VSpan(LineGlyph):
+    """ Vertical lines of infinite height. """
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+    __example__ = "examples/reference/models/VSpan.py"
+
+    _args = ("x")
+
+    x = NumberSpec(default=field("x"), help="""
+    The x-coordinates of the spans.
+    """)
+
+    line_props = Include(LineProps, help="""
+    The {prop} values for the spans.
+    """)
+
+class HStrip(LineGlyph, FillGlyph, HatchGlyph):
+    """ Horizontal strips of infinite width. """
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+    __example__ = "examples/reference/models/HStrip.py"
+
+    _args = ("y0", "y1")
+
+    y0 = NumberSpec(default=field("y0"), help="""
+    The y-coordinates of the coordinates of one side of the strips.
+    """)
+
+    y1 = NumberSpec(default=field("y1"), help="""
+    The y-coordinates of the coordinates of the other side of the strips.
+    """)
+
+    line_props = Include(LineProps, help="""
+    The {prop} values for the strips.
+    """)
+
+    fill_props = Include(FillProps, help="""
+    The {prop} values for the strips.
+    """)
+
+    hatch_props = Include(HatchProps, help="""
+    The {prop} values for the strips.
+    """)
+
+class VStrip(LineGlyph, FillGlyph, HatchGlyph):
+    """ Vertical strips of infinite height. """
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+    __example__ = "examples/reference/models/VStrip.py"
+
+    _args = ("x0", "x1")
+
+    x0 = NumberSpec(default=field("x0"), help="""
+    The x-coordinates of the coordinates of one side of the strips.
+    """)
+
+    x1 = NumberSpec(default=field("x1"), help="""
+    The x-coordinates of the coordinates of the other side of the strips.
+    """)
+
+    line_props = Include(LineProps, help="""
+    The {prop} values for the strips.
+    """)
+
+    fill_props = Include(FillProps, help="""
+    The {prop} values for the strips.
+    """)
+
+    hatch_props = Include(HatchProps, help="""
+    The {prop} values for the strips.
+    """)
+
 #-----------------------------------------------------------------------------
 # Dev API
 #-----------------------------------------------------------------------------
