@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -22,7 +22,6 @@ log = logging.getLogger(__name__)
 
 # Standard library imports
 import os
-import sys
 from pathlib import Path
 
 # External imports
@@ -68,7 +67,7 @@ class MultiRootStaticHandler(StaticFileHandler):
 
     def validate_absolute_path(self, root: dict[str, PathLike], absolute_path: str) -> str | None:
         for artifacts_dir in root.values():
-            if is_relative_to(Path(absolute_path), artifacts_dir):
+            if Path(absolute_path).is_relative_to(artifacts_dir):
                 return super().validate_absolute_path(str(artifacts_dir), absolute_path)
 
         return None
@@ -77,18 +76,6 @@ class MultiRootStaticHandler(StaticFileHandler):
 # Private API
 #-----------------------------------------------------------------------------
 
-if sys.version_info > (3, 9):
-    def is_relative_to(path: Path, *other: PathLike) -> bool:
-        return path.is_relative_to(*other)
-else:
-    def is_relative_to(path: Path, *other: PathLike) -> bool:
-        """Return True if the path is relative to another path or False. """
-        try:
-            path.relative_to(*other)
-            return True
-        except ValueError:
-            return False
-
 #-----------------------------------------------------------------------------
 # Code
 #-----------------------------------------------------------------------------
